package com.taauav.admin.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotEmpty;
import java.io.Serializable;

/**
 * <p>
 * 用户组表
 * </p>
 *
 * @author dyg
 * @since 2019-11-04
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("sys_auth_group")
public class SysAuthGroup implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 编号
     */
    @TableId(value = "id", type = IdType.AUTO)
    private Integer id;

    /**
     * 父级ID
     */
    private Integer pid;

    /**
     * 用户组中文名称
     */
    @NotEmpty(message = "角色名称不能为空")
    @Length(min = 2, max = 10, message = "角色名称长度为2-10个字")
    private String name;

    /**
     * 有无子级：1有 2无
     */
    private Byte hasChild;

    /**
     * 角色层级
     */
    private Byte level;

    /**
     * 用户组拥有的规则id，多个规则","隔开
     */
    private String rules;

    /**
     * 备注
     */
    @Length(max = 200, message = "备注不能超过200字")
    private String remark;

    /**
     * 状态：1正常 2禁用
     */
    private Byte status;

    /**
     * 排序
     */
    private Integer sort;

    /**
     * 创建人
     */
    private Integer createUser;

    /**
     * 更新人
     */
    private Integer updateUser;

    /**
     * 创建时间
     */
    private Integer createTime;

    /**
     * 更新时间
     */
    private Integer updateTime;

    /**
     * 有效标记
     */
    private Byte mark;

    @Override
    public String toString() {
        return "SysAuthGroup{" +
                "id=" + id +
                ", pid=" + pid +
                ", name='" + name + '\'' +
                ", hasChild=" + hasChild +
                ", level=" + level +
                ", rules='" + rules + '\'' +
                ", remark='" + remark + '\'' +
                ", status=" + status +
                ", sort=" + sort +
                ", createUser=" + createUser +
                ", updateUser=" + updateUser +
                ", createTime=" + createTime +
                ", updateTime=" + updateTime +
                ", mark=" + mark +
                '}';
    }
}
