package com.taauav.admin.entity;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.taauav.common.domain.Entity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.*;
import javax.websocket.ClientEndpoint;

/**
 * <p>
 * 河道管理表
 * </p>
 *
 * @author dyg
 * @since 2019-11-12
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("tauv_driver")
public class TauvDriver extends Entity {

    private static final long serialVersionUID = 1L;

    /**
     * 河道名称
     */
    @NotEmpty(message = "河道名称不能为空")
    @Length(min = 2, max = 20, message = "河道名称长度为2-20个字")
    private String name;

    /**
     * 河道类型：1河流 2水库 3湖泊 4重点塘坝
     */
    @NotNull(message = "请选择河道类型")
    private Byte type;

    /**
     * 河道长度(单位：km)
     */
    @NotEmpty(message = "长度不能为空")
    private String length;

    /**
     * 是否省/国考河道：1是 2否
     */
    private Byte isExam;

    /**
     * 起点
     */
    @Length(max = 20, message = "起点长度不能超过20个字")
    private String startPoint;

    /**
     * 终点
     */
    @Length(max = 20, message = "终点长度不能超过20个字")
    private String endPoint;

    /**
     * 国考河道长度(单位：km)
     */
    private String examLength;

    /**
     * 河道所属区域
     */
    private Integer driverArea;

    private String driverCode;


    /**
     * 河流类型
     * @return
     */
    public Map<Integer,String> getTypeList() {
        Map<Integer,String> map = new HashMap<>(4);
        map.put(1,"河流");
        map.put(2,"水库");
        map.put(3,"湖泊");
        map.put(4,"重点塘坝");
        return map;
    }

    /**
     * 是否省/国考河道
     * @return
     */
    public Map<Integer,String> getExamList() {
        Map<Integer,String> map = new HashMap<>(2);
        map.put(1,"是");
        map.put(2,"否");
        return map;
    }

    /**
     * 状态
     * @return
     */
    public Map<Integer,String> getStatusList() {
        Map<Integer,String> map = new HashMap<>(2);
        map.put(1,"正常");
        map.put(2,"停用");
        return map;
    }
}
