package com.taauav.admin.entity;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotEmpty;

/**
 * <p>
 * 设备管理表
 * </p>
 *
 * @author dyg
 * @since 2019-11-13
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class TauvEquipment implements Serializable {

    private static final long serialVersionUID = 1L;
    @TableId(value = "id",type = IdType.AUTO)
    private Integer id;
    /**
     * 产品序号
     */
    @NotEmpty(message = "产品序号不能空")
    @Length(min = 2, max = 150, message = "产品序号长度为2-150个字")
    private String productSn;

    /**
     * 飞控序号
     */
    @Length(max = 150, message = "飞控序号长度不能超过150个字")
    private String flightSn;

    /**
     * 无人机登记号
     */
    @Length(max = 150, message = "无人机登记号长度不能超过150个字")
    private String droneNum;

    /**
     * 设备名称
     */
    @NotEmpty(message = "设备名称不能为空")
    @Length(min = 2, max = 20, message = "设备名称长度为2-20个字")
    private String name;

    /**
     * 品牌
     */
    @Length(max = 100, message = "品牌长度不能超过100个字")
    private String brand;

    /**
     * 型号
     */
    @Length(max = 100, message = "型号长度不能超过100个字")
    private String model;

    /**
     * 类型：1多旋翼 2固定翼
     */
    private Byte type;

    /**
     * 注册时间
     */
    private Integer registerTime;

    /**
     * 状态：1正常 2停用
     */
    private Byte status;

    /**
     * 创建人
     */
    private Integer createUser;

    /**
     * 更新人
     */
    private Integer updateUser;

    /**
     * 创建时间
     */
    private Integer createTime;

    /**
     * 更新时间
     */
    private Integer updateTime;

    /**
     * 有效标记
     */
    private Byte mark;

    public Map<Integer,String> getStatusList() {
        Map<Integer,String> map = new HashMap<>();
        map.put(1,"正常");
        map.put(2,"停用");
        return map;
    }

    public Map<Integer,String> getTypeList() {
        Map<Integer,String> map = new HashMap<>();
        map.put(1,"多旋翼");
        map.put(2,"固定翼");
        return map;
    }
}
