package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.entity.SysCity;
import com.taauav.admin.mapper.SysAdminMapper;
import com.taauav.admin.mapper.SysCityMapper;
import com.taauav.admin.mapper.TauvDriverMapper;
import com.taauav.admin.service.ISysCityService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 城市表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-13
 */
@Service
public class SysCityServiceImpl extends ServiceImpl<SysCityMapper, SysCity> implements ISysCityService {
    @Autowired
    private SysCityMapper sysCityMapper;
    @Autowired
    private SysAdminMapper adminMapper;
    @Autowired
    private TauvDriverMapper tauvDriverMapper;
    @Resource
    private Response response;

    /**
     * 根据上级编号获取数据
     * @param pid
     * @return
     */
    @Override
    public List<Map<String, Object>> getCityListByPid(Integer pid) {
        QueryWrapper<SysCity> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("pid", pid);
        queryWrapper.eq("mark",1);
        queryWrapper.select("id,pid,name,longitude,latitude");
        List<Map<String,Object>> list = sysCityMapper.selectMaps(queryWrapper);
        return list;
    }

    /**
     * 根据父级id和用户城市权限获取城市列表
     * @param pid
     * @return
     */
    @Override
    public List<Map<String, Object>> getCityListByPidAndAdmin(Integer pid) {
        Integer adminId = ShiroUtils.getAdminId();
        SysAdmin admin = adminMapper.selectById(adminId);
        if (!"".equals(admin.getCityIds())) {
            QueryWrapper<SysCity> wrapper = new QueryWrapper<>();
            String[] ids = admin.getCityIds().split(",");
            wrapper.eq("pid", pid);
            wrapper.eq("mark", 1);
            wrapper.in("id", ids);
            wrapper.select("id,pid,name,longitude,latitude");
            List<Map<String,Object>> list = sysCityMapper.selectMaps(wrapper);
            return list;
        } else {
            return null;
        }
    }

    @Override
    public SysCity getInfoById(Integer id) {
        return sysCityMapper.selectById(id);
    }

    /**
     * 获取城市各辖区河道信息
     * @param cityId
     * @return
     */
    @Override
    public Response getCityDriverList(Integer cityId) {
        List<Map<String, Object>> cityList = getCityListByPid(cityId);
        if (cityList != null) {
            for (Map<String, Object> city : cityList) {
                QueryWrapper wrapper = new QueryWrapper();
                wrapper.eq("mark", 1);
                wrapper.eq("status", 1);
                wrapper.eq("driver_area", city.get("id"));
                Integer num = tauvDriverMapper.selectCount(wrapper);
                city.put("count", num);
            }
        }
        return response.success(cityList);
    }
}
