package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.taauav.common.bean.Response;
import com.taauav.admin.entity.SysAdmin;
import com.taauav.admin.entity.TauvDriver;
import com.taauav.admin.mapper.TauvDriverMapper;
import com.taauav.admin.service.ISysAdminService;
import com.taauav.admin.service.ISysCityService;
import com.taauav.admin.service.ITauvDriverService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.validation.Valid;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 河道管理表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-12
 */
@Service
public class TauvDriverServiceImpl extends BaseServiceImpl<TauvDriverMapper, TauvDriver> implements ITauvDriverService {
    @Value("${spring.pageSize}")
    private Integer pageSize;
    @Autowired
    private Response response;

    @Autowired
    private ISysCityService iSysCityService;
    @Autowired
    private ISysAdminService iSysAdminService;

    /**
     * 获取河道分页数据
     * @param map
     * @return
     */
    @Override
    public Response getPageList(Map<String, String> map) {
        QueryWrapper<TauvDriver> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mark",1);
        Integer pageNo = 1;
        if (map != null) {
            if (map.containsKey("name") && !"".equals(map.get("name"))) {
                queryWrapper.like("name", map.get("name"));
            }
            if (map.containsKey("type") && !"".equals(map.get("type"))) {
                queryWrapper.eq("type", Integer.valueOf(map.get("type")));
            }
            if (map.containsKey("is_exam") && !"".equals(map.get("is_exam"))) {
                queryWrapper.eq("is_exam", Integer.valueOf(map.get("is_exam")));
            }
            if (map.containsKey("driver_area") && !"".equals(map.get("driver_area"))) {
                queryWrapper.eq("driver_area", Integer.valueOf(map.get("driver_area")));
            }
            //每页数量
            String pgSize = "pageSize";
            if (map.containsKey(pgSize) && Integer.valueOf(map.get(pgSize)) > 0) {
                pageSize = Integer.valueOf(map.get(pgSize));
            }
            //页数
            if (map.containsKey("page") && !"".equals(map.get("page")) && Integer.valueOf(map.get("page")) > 0) {
                pageNo = Integer.valueOf(map.get("page"));
            }
        }

        IPage<TauvDriver> page = new Page<>(pageNo,pageSize);
        IPage<TauvDriver> data =  getBaseMapper().selectPage(page, queryWrapper);
        return response.success(data);
    }

    /**
     * 修改河道数据
     * @param driver
     * @return
     */
    @Override
    public Response edit(TauvDriver driver) {
        if (StringUtils.isEmpty(driver)) {
            return response.failure("数据不存在");
        }
        TauvDriver info = getInfoById(driver.getId());
        if (StringUtils.isEmpty(info)) {
            return response.failure("数据不存在");
        }
        editData(driver);
        return response.success("操作成功");
    }

    /**
     * 添加河道数据
     * @param driver
     * @return
     */
    @Override
    public Response add(TauvDriver driver) {
        String name = driver.getName();
        TauvDriver info = getInfoByName(name);
        if (!StringUtils.isEmpty(info)) {
            return response.failure("河道名称已经存在");
        }
        addData(driver);
        return response.success("添加成功");
    }

    /**
     * 根据编号获取数据
     * @param id
     * @return
     */
    @Override
    public TauvDriver getInfoById(Integer id) {
        return getInfo(id);
    }

    /**
     * 根据编号获取详细数据
     * @param info
     * @return
     */
    @Override
    public Map<String, Object> getInfoDetail(TauvDriver info) {
        Map<String,Object> map = new HashMap<>();
        TauvDriver driver = new TauvDriver();
        map.put("name",info.getName());
        map.put("driver_area",info.getDriverArea());
        map.put("type",info.getType());
        map.put("length",info.getLength());
        map.put("is_exam",info.getIsExam());
        map.put("start_point",info.getStartPoint());
        map.put("end_point",info.getEndPoint());
        map.put("exam_length",info.getExamLength());
        map.put("exam_list",driver.getExamList());
        map.put("type_list",driver.getTypeList());
        map.put("area_list",iSysCityService.getCityListByPid(320100));
        map.put("format_create_time", DateUtil.format(info.getCreateTime(),"yyyy-MM-dd HH:mm:ss"));
        SysAdmin adminInfo = null;
        if (info.getCreateUser() > 0) {
            adminInfo = iSysAdminService.findById(info.getCreateUser());
        }
        map.put("format_create_user",StringUtils.isEmpty(adminInfo) ? "" : adminInfo.getRealname());
        return map;
    }

    /**
     * 根据河道名称获取数据
     * @param name
     * @return
     */
    @Override
    public TauvDriver getInfoByName(String name) {
        QueryWrapper<TauvDriver> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("mark",1);
        queryWrapper.eq("name",name);
        TauvDriver info = getOne(queryWrapper);
        return info;
    }

    /**
     * 基础数据数据
     * @return
     */
    @Override
    public Map<String, Object> getBaseData() {
        TauvDriver driver = new TauvDriver();
        Map<String,Object> map = new HashMap<>(3);
        map.put("type_list",driver.getTypeList());
        map.put("exam_list",driver.getExamList());
        map.put("area_list",iSysCityService.getCityListByPid(320100));
        return map;
    }

    /**
     * 获取所有河道数据
     * @return
     */
    @Override
    public Response getDriverList() {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("mark", 1);
        wrapper.eq("status", 1);
        List<Map<String, Object>> list = list(wrapper);
        return response.success("操作成功", list);
    }
}
