package com.taauav.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.taauav.common.bean.Response;
import com.taauav.admin.entity.TauvEquipment;
import com.taauav.admin.mapper.TauvEquipmentMapper;
import com.taauav.admin.service.ITauvEquipmentService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * <p>
 * 设备管理表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-13
 */
@Service
public class TauvEquipmentServiceImpl extends ServiceImpl<TauvEquipmentMapper, TauvEquipment> implements ITauvEquipmentService {
    @Value("${spring.pageSize}")
    private Integer pageSize;
    @Autowired
    private TauvEquipmentMapper equipmentMapper;
    @Autowired
    private Response response;
    @Override
    public Response getPageList(Map<String, String> map) {
        QueryWrapper<TauvEquipment> queryWrapper = new QueryWrapper<TauvEquipment>();
        queryWrapper.eq("mark",1);
        Integer pageNo = 1;
        if (map != null) {
            //每页数量
            String pgSize = "pageSize";
            if (map.containsKey(pgSize) && Integer.valueOf(map.get(pgSize)) > 0) {
                pageSize = Integer.valueOf(map.get(pgSize));
            }
            //页数
            if (map.containsKey("page") && !"".equals(map.get("page")) && Integer.valueOf(map.get("page")) > 0) {
                pageNo = Integer.valueOf(map.get("page"));
            }
        }
        IPage<TauvEquipment> page = new Page<>(pageNo, pageSize);
        IPage<Map<String,Object>> data =  equipmentMapper.selectMapsPage(page,queryWrapper);
        TauvEquipment tauvEquipment = new TauvEquipment();
        Map<Integer,String> statusList = tauvEquipment.getStatusList();
        if (!StringUtils.isEmpty(data.getRecords())) {
            for (Map<String,Object> mp : data.getRecords()) {
                mp.put("statusText",statusList.get(mp.get("status")));
                Integer registerTime = new Long(mp.get("register_time").toString()).intValue();
                mp.put("format_register_time", FunctionUtils.formatTime(registerTime,"yyyy-MM-dd HH:mm:ss"));
            }
        }

        return response.success(data);
    }

    /**
     * 编辑设备数据
     * @param equipment
     * @return
     */
    @Override
    public Response edit(TauvEquipment equipment) {
        equipment.setUpdateTime(FunctionUtils.getCurrentTime());
        equipment.setUpdateUser(ShiroUtils.getAdminId());
        equipmentMapper.updateById(equipment);
        return response.success("操作成功");
    }

    /**
     * 添加设备数据
     * @param equipment
     * @return
     */
    @Override
    public Response add(TauvEquipment equipment) {
        equipment.setCreateTime(FunctionUtils.getCurrentTime());
        equipment.setCreateUser(ShiroUtils.getAdminId());
        equipmentMapper.insert(equipment);
        return response.success("操作成功");
    }

    /**
     * 修改状态
     * @param map
     * @return
     */
    @Override
    public Response setRules(Map<String, String> map) {
        if (StringUtils.isEmpty(map)) {
            return response.failure("参数不能为空");
        }
        String idStr = map.getOrDefault("id","");
        String statusStr = map.getOrDefault("status","");
        if (StringUtils.isEmpty(idStr)) {
            return response.failure("编号不存在");
        }
        if (StringUtils.isEmpty(statusStr)) {
            return response.failure("状态不能为空");
        }
        if (!("1".equals(statusStr) || "2".equals(statusStr))) {
            return response.failure("状态值不合法");
        }
        TauvEquipment tauvEquipment = new TauvEquipment();
        tauvEquipment.setStatus(Byte.valueOf(statusStr));
        tauvEquipment.setId(Integer.valueOf(idStr));
        equipmentMapper.updateById(tauvEquipment);
        return response.success("操作成功");
    }

    /**
     * 根据编号获取数据
     * @param id
     * @return
     */
    @Override
    public TauvEquipment getInfoById(Integer id) {
        if (StringUtils.isEmpty(id)) {
            return null;
        }
        return equipmentMapper.selectById(id);
    }

    /**
     * 分类和状态等数据
     * @return
     */
    @Override
    public Map<String, Object> getBaseData() {
        TauvEquipment equipment = new TauvEquipment();
        Map<String,Object> map = new HashMap<>(2);
        map.put("type_list",equipment.getTypeList());
        map.put("status_list",equipment.getStatusList());
        return map;
    }
}
