package com.taauav.admin.service.impl;

import com.taauav.common.bean.Response;
import com.taauav.admin.entity.TauvInspect;
import com.taauav.admin.mapper.TauvInspectMapper;
import com.taauav.admin.service.ITauvInspectDriverService;
import com.taauav.admin.service.ITauvInspectService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

/**
 * <p>
 * 巡检任务表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
@Service
public class TauvInspectServiceImpl extends ServiceImpl<TauvInspectMapper, TauvInspect> implements ITauvInspectService {
    @Autowired
    private Response response;
    @Autowired
    private TauvInspectMapper inspectMapper;
    @Autowired
    private ITauvInspectDriverService iTauvInspectDriverService;

    /**
     * 添加任务
     * @param inspect
     * @return
     */
    @Override
    public Response addTask(TauvInspect inspect) {
        Integer type = inspect.getType().intValue();
        if (type.equals(2) && StringUtils.isEmpty(inspect.getExecutionCycle())) {
            return response.failure("巡检周期不能为空");
        }
        inspect.setCreateTime(FunctionUtils.getCurrentTime());
        inspect.setCreateUser(ShiroUtils.getAdminId());
        inspectMapper.insert(inspect);
        //生成巡检任务单号
        String code = "";
        if (type == 2) {
            code = "ZQ" + FunctionUtils.formatTime(FunctionUtils.getCurrentTime(), "yyyyMM");
        } else {
            code = "RC" + FunctionUtils.formatTime(FunctionUtils.getCurrentTime(), "yyyyMM");
        }
        Integer id = inspect.getId();
        String idStr = String.format("%04d", id);
        inspect.setId(id);
        inspect.setInspectNo(code + idStr);
        saveOrUpdate(inspect);
        String msg = iTauvInspectDriverService.batchAddData(inspect);
        if (!"".equals(msg)) {
            return response.failure(msg);
        }
        return response.success("添加成功");
    }

    @Override
    public TauvInspect getInfoById(Integer id) {
        return inspectMapper.selectById(id);
    }
}
